==> 2.3.0-beta3&file=out_yasapi-nt-2.3.0-beta3-src.tar.gz: out_yasapi-nt-2.3.0-beta3/gyasapi_defines.h <==
/*
 * yasapi_defines.h
 *
 * Yet Another (WA)SAPI (YASAPI) New Technology (NT) Output (out_yasapi-nt)
 * Copyright (C) 2015-2019  Peter Belkner (pbelkner@snafu.de)
 *
 * out_yasapi-nt is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * out_yasapi-nt is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with out_yasapi-nt.  If not, see <https://www.gnu.org/licenses/>.
 */
#ifndef __YASAPI_DEFINES_H__ // [
#define __YASAPI_DEFINES_H__

#ifdef __cplusplus // [
extern "C" {
#endif // ]

///////////////////////////////////////////////////////////////////////////////
#if defined (_MSC_VER) // [
#define __func__ __FUNCTION__
#endif // ]
#define YASAPI_FILE_OPEN_DIALOG

///////////////////////////////////////////////////////////////////////////////
// https://gustedt.wordpress.com/2010/06/16/associativity-of-double-constants-and-preprocessor-tokens/
#define YASAPI_PASTE2(a, b) \
  a ## b
#define _YASAPI_PASTE2(a, b) \
  YASAPI_PASTE2(a, b)
#define YASAPI_PASTE3(a, b, c) \
  _YASAPI_PASTE2(YASAPI_PASTE2(a, b), c)
#define YASAPI_PASTE4(a, b, c, d) \
  _YASAPI_PASTE2(YASAPI_PASTE3(a, b, c), d)
#define YASAPI_PASTE5(a, b, c, d, e) \
  _YASAPI_PASTE2(YASAPI_PASTE4(a, b, c, d), e)
#define YASAPI_PASTE6(a, b, c, d, e, f) \
  _YASAPI_PASTE2(YASAPI_PASTE5(a, b, c, d, e), f)

#define _YASAPI_STRA(id) \
    #id
#define YASAPI_STRA(id) \
    _YASAPI_STRA(id)
#define _YASAPI_STRW(id) \
    L ## #id
#define YASAPI_STRW(id) \
    _YASAPI_STRW(id)

#define YASAPI_INC_UINT32(u) \
    (UINT32_MAX==(u)?(u)=1lu:++(u))
#define YASAPI_ADD_UINT32(u,amount) do { \
  if (UINT32_MAX==(u)) (u)=(amount); else (u)+=(amount); \
} while (0)
#define YASAPI_DOUBLE_INVALID(x) \
  isnan(x)
#define YASAPI_DOUBLE_INVALIDATE(x) \
  x=NAN
#define YASAPI_ADD_DOUBLE(x,amount) do { \
  if (YASAPI_DOUBLE_INVALID(x)) (x)=(amount); else (x)+=(amount); \
} while (0)
#define YASAPI_ARRAYSIZE(a) \
  (sizeof (a))/(sizeof (a)[0])

///////////////////////////////////////////////////////////////////////////////
#define YASAPI_VERSION \
    YASAPI_PASTE5(2,.,3,.,0)

#if defined (__GNUC__) // [
#define YASAPI_TITLE_SFX " (gcc)"
#define YASAPI_TITLE_SFX_U8 " (gcc)"
#define YASAPI_TITLE_SFX_U16 L" (gcc)"
#elif defined (_MSC_VER) // ] [
#define YASAPI_TITLE_SFX " (msc)"
#define YASAPI_TITLE_SFX_U8 " (msc)"
#define YASAPI_TITLE_SFX_U16 L" (msc)"
#else // ] [
#define YASAPI_TITLE_SFX ""
#define YASAPI_TITLE_SFX_U8 ""
#define YASAPI_TITLE_SFX_U16 L""
#endif // ]

#define YASAPI_VERSION_SFX "-beta" YASAPI_STRA(YASAPI_BETA)
#define YASAPI_VERSION_SFX_U8 "-\316\262" YASAPI_STRA(YASAPI_BETA)
#define YASAPI_VERSION_SFX_U16 L"-\x03B2" YASAPI_STRW(YASAPI_BETA)

#define YASAPI_VERSION_CS YASAPI_STRA(YASAPI_VERSION) YASAPI_VERSION_SFX
#define YASAPI_VERSION_U8 YASAPI_STRA(YASAPI_VERSION) YASAPI_VERSION_SFX_U8
#define YASAPI_VERSION_U16 YASAPI_STRW(YASAPI_VERSION) YASAPI_VERSION_SFX_U16

#define YASAPI_TITLE "YASAPI/NT Output v" YASAPI_VERSION_CS \
    YASAPI_TITLE_SFX " #TeamWhite"
#define YASAPI_TITLE_U8 "YASAPI/NT Output v" YASAPI_VERSION_U8 \
    YASAPI_TITLE_SFX_U8 " #TeamWhite"
#define YASAPI_TITLE_U16 L"YASAPI/NT Output v" YASAPI_VERSION_U16 \
    YASAPI_TITLE_SFX_U16 L" #TeamWhite"

///////////////////////////////////////////////////////////////////////////////
#define DMESSAGEEX(file,line,func,format) \
    yasapi_message(file,line,format,0ul)
#define DMESSAGE(format) \
    DMESSAGEEX(__FILE__,__LINE__,__func__,format)
#define DVMESSAGEEX(file,line,func,format,...) \
    yasapi_message(file,line,format,0ul,__VA_ARGS__)
#define DVMESSAGE(format,...) \
    DVMESSAGEEX(__FILE__,__LINE__,__FUNC__,format,__VA_ARGS__)

#define DCMESSAGE(m,label) case label: \
    DMESSAGE(m " failed with " #label); \
    break
#define DVCMESSAGE(m,label,...) case label: \
    DVMESSAGE(m " failed with " #label,__VA_ARGS__); \
    break
#define DDMESSAGE(m,hr) default: \
    DVMESSAGE(m " failed with unknown %p",hr); \
    break
#define DVDMESSAGE(m,hr,...) default: \
    DVMESSAGE(m " failed with unknown %p",__VA_ARGS__,hr); \
    break

#define DASSERT(condition,label)
#define DASSERT_ENGINE_STATE(pEngine,_eState,label)
#define DLABEL(label)

///////////////////////////////////////////////////////////////////////////////
#define DMARKLN()
#define DWRITELNEX(file,line,func,format)
#define DWRITELN(s)
#define DWRITELNW(s)
#define DVWRITELNEX(file,line,func,format,...)
#define DVWRITELN(format,...)
#define DVWRITELNW(format,...)
#define DGETC()
#define DSLEEP(ms)

///////////////////////////////////////////////////////////////////////////////
#define YASAPI_MS2FRAMES(ms,pwfx) \
  MulDiv(ms,(pwfx)->Format.nSamplesPerSec,1000)
#define YASAPI_FRAMES2MS(uNumFrames,pwfx) \
  MulDiv(1000,uNumFrames,(pwfx)->Format.nSamplesPerSec)
#define YASAPI_FRAMES2MS_DOUBLE(xNumFrames,pwfx) \
  (1000.0*xNumFrames/(pwfx)->Format.nSamplesPerSec)
#define YASAPI_FRAMES2HNS(xNumFrames,pwfx) \
  (10.0*1000.0*YASAPI_FRAMES2MS_DOUBLE(xNumFrames,pwfx))
#define YASAPI_SIZE2FRAMES(dwSize,pwfx) \
  MulDiv(1,dwSize,(pwfx)->Format.nBlockAlign)

#ifdef __cplusplus // [
}
#endif // ]
#endif // __YASAPI_DEFINES_H__ ]

==> 2.3.3-beta3&file=out_yasapi-nt-2.3.3-beta3-src.tar.gz: out_yasapi-nt-2.3.3-beta3/gyasapi_defines.h <==
/*
 * yasapi_defines.h
 *
 * Yet Another (WA)SAPI (YASAPI) New Technology (NT) Output (out_yasapi-nt)
 * Copyright (C) 2015-2019  Peter Belkner (pbelkner@snafu.de)
 *
 * out_yasapi-nt is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * out_yasapi-nt is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with out_yasapi-nt.  If not, see <https://www.gnu.org/licenses/>.
 */
#ifndef __YASAPI_DEFINES_H__ // [
#define __YASAPI_DEFINES_H__

#ifdef __cplusplus // [
extern "C" {
#endif // ]

///////////////////////////////////////////////////////////////////////////////
#if defined (_MSC_VER) // [
#define __func__ __FUNCTION__
#endif // ]
//#define YASAPI_FILE_OPEN_DIALOG

///////////////////////////////////////////////////////////////////////////////
// https://gustedt.wordpress.com/2010/06/16/associativity-of-double-constants-and-preprocessor-tokens/
#define YASAPI_PASTE2(a, b) \
  a ## b
#define _YASAPI_PASTE2(a, b) \
  YASAPI_PASTE2(a, b)
#define YASAPI_PASTE3(a, b, c) \
  _YASAPI_PASTE2(YASAPI_PASTE2(a, b), c)
#define YASAPI_PASTE4(a, b, c, d) \
  _YASAPI_PASTE2(YASAPI_PASTE3(a, b, c), d)
#define YASAPI_PASTE5(a, b, c, d, e) \
  _YASAPI_PASTE2(YASAPI_PASTE4(a, b, c, d), e)
#define YASAPI_PASTE6(a, b, c, d, e, f) \
  _YASAPI_PASTE2(YASAPI_PASTE5(a, b, c, d, e), f)

#define _YASAPI_STRA(id) \
    #id
#define YASAPI_STRA(id) \
    _YASAPI_STRA(id)
#define _YASAPI_STRW(id) \
    L ## #id
#define YASAPI_STRW(id) \
    _YASAPI_STRW(id)

#define YASAPI_INC_UINT32(u) \
    (UINT32_MAX==(u)?(u)=1lu:++(u))
#define YASAPI_ADD_UINT32(u,amount) do { \
  if (UINT32_MAX==(u)) (u)=(amount); else (u)+=(amount); \
} while (0)
#define YASAPI_DOUBLE_INVALID(x) \
  isnan(x)
#define YASAPI_DOUBLE_INVALIDATE(x) \
  x=NAN
#define YASAPI_ADD_DOUBLE(x,amount) do { \
  if (YASAPI_DOUBLE_INVALID(x)) (x)=(amount); else (x)+=(amount); \
} while (0)
#define YASAPI_ARRAYSIZE(a) \
  (sizeof (a))/(sizeof (a)[0])

///////////////////////////////////////////////////////////////////////////////
#define YASAPI_FSM_UP(pFsm,eState) \
  FsmUp(pFsm,eState,__FILE__,__LINE__,__func__)
#define YASAPI_FSM_BACKTRACK(pFsm,eState) \
  FsmBacktrack(pFsm,eState,__FILE__,__LINE__,__func__)
#define YASAPI_FSM_DOWN(pFsm,eState) \
  FsmDown(pFsm,eState )
#define YASAPI_REQUEST_STATE(pFsm,eState) \
  EngineClientRequestServerState(pFsm,eState,__FILE__,__LINE__,__func__)
#define YASAPI_PLAYER_LOCK(pPlayer) \
  PlayerLock(pPlayer )
#define YASAPI_PLAYER_UNLOCK(pPlayer) \
  PlayerUnlock(pPlayer)
#define YASAPI_PLAYER_LOCK_DEEP(pPlayer,nRecursion) \
  PlayerLockDeep(pPlayer,nRecursion )
#define YASAPI_PLAYER_UNLOCK_DEEP(pPlayer,pnRecursion) \
  PlayerUnlockDeep(pPlayer,pnRecursion)

///////////////////////////////////////////////////////////////////////////////
#define YASAPI_VERSION \
  YASAPI_PASTE5(2,.,3,.,3)

#if defined (__GNUC__) // [
#define YASAPI_TITLE_SFX " (gcc)"
#define YASAPI_TITLE_SFX_U8 " (gcc)"
#define YASAPI_TITLE_SFX_U16 L" (gcc)"
#elif defined (_MSC_VER) // ] [
#define YASAPI_TITLE_SFX " (msc)"
#define YASAPI_TITLE_SFX_U8 " (msc)"
#define YASAPI_TITLE_SFX_U16 L" (msc)"
#else // ] [
#define YASAPI_TITLE_SFX ""
#define YASAPI_TITLE_SFX_U8 ""
#define YASAPI_TITLE_SFX_U16 L""
#endif // ]

#define YASAPI_VERSION_SFX "-beta" YASAPI_STRA(YASAPI_BETA)
#define YASAPI_VERSION_SFX_U8 "-\316\262" YASAPI_STRA(YASAPI_BETA)
#define YASAPI_VERSION_SFX_U16 L"-\x03B2" YASAPI_STRW(YASAPI_BETA)

#define YASAPI_VERSION_CS YASAPI_STRA(YASAPI_VERSION) YASAPI_VERSION_SFX
#define YASAPI_VERSION_U8 YASAPI_STRA(YASAPI_VERSION) YASAPI_VERSION_SFX_U8
#define YASAPI_VERSION_U16 YASAPI_STRW(YASAPI_VERSION) YASAPI_VERSION_SFX_U16

#define YASAPI_TITLE "YASAPI/NT Output v" YASAPI_VERSION_CS \
    YASAPI_TITLE_SFX " #TeamWhite"
#define YASAPI_TITLE_U8 "YASAPI/NT Output v" YASAPI_VERSION_U8 \
    YASAPI_TITLE_SFX_U8 " #TeamWhite"
#define YASAPI_TITLE_U16 L"YASAPI/NT Output v" YASAPI_VERSION_U16 \
    YASAPI_TITLE_SFX_U16 L" #TeamWhite"

///////////////////////////////////////////////////////////////////////////////
#define DMESSAGEEX(file,line,func,format) \
    yasapi_message(file,line,format,0ul)
#define DMESSAGE(format) \
    DMESSAGEEX(__FILE__,__LINE__,__func__,format)
#define DVMESSAGEEX(file,line,func,format,...) \
    yasapi_message(file,line,format,0ul,__VA_ARGS__)
#define DVMESSAGE(format,...) \
    DVMESSAGEEX(__FILE__,__LINE__,__FUNC__,format,__VA_ARGS__)

#define DCMESSAGE(m,label) case label: \
    DMESSAGE(m " failed with " #label); \
    break
#define DVCMESSAGE(m,label,...) case label: \
    DVMESSAGE(m " failed with " #label,__VA_ARGS__); \
    break
#define DDMESSAGE(m,hr) default: \
    DVMESSAGE(m " failed with unknown %p",hr); \
    break
#define DVDMESSAGE(m,hr,...) default: \
    DVMESSAGE(m " failed with unknown %p",__VA_ARGS__,hr); \
    break

#define DASSERT(condition,label)
#define DASSERT_ENGINE_STATE(pEngine,_eState,label)
#define DLABEL(label)

///////////////////////////////////////////////////////////////////////////////
#define DMARKLN()
#define DWRITELNEX(file,line,func,format)
#define DWRITELN(s)
#define DWRITELNW(s)
#define DVWRITELNEX(file,line,func,format,...)
#define DVWRITELN(format,...)
#define DVWRITELNW(format,...)
#define DGETC()
#define DSLEEP(ms)

///////////////////////////////////////////////////////////////////////////////
#define YASAPI_MS2FRAMES(ms,pwfx) \
  MulDiv(ms,(pwfx)->Format.nSamplesPerSec,1000)
#define YASAPI_HNS2FRAMES(ms,pwfx) \
  ((double)(ms)*(pwfx)->Format.nSamplesPerSec/(10.0*1000.0*1000.0))
#define YASAPI_FRAMES2MS(uNumFrames,pwfx) \
  MulDiv(1000,uNumFrames,(pwfx)->Format.nSamplesPerSec)
#define YASAPI_FRAMES2MS_DOUBLE(xNumFrames,pwfx) \
  (1000.0*xNumFrames/(pwfx)->Format.nSamplesPerSec)
#define YASAPI_FRAMES2HNS(xNumFrames,pwfx) \
  (10.0*1000.0*YASAPI_FRAMES2MS_DOUBLE(xNumFrames,pwfx))
#define YASAPI_SIZE2FRAMES(dwSize,pwfx) \
  MulDiv(1,dwSize,(pwfx)->Format.nBlockAlign)

#ifdef __cplusplus // [
}
#endif // ]
#endif // __YASAPI_DEFINES_H__ ]
